@@ -336,10 +336,10 @@ def make_injection(signal, f_src, amplitude, src_pos, name, detector="H", delay=
     Take a real signal and inject a sinusoidal signal in use CUDA kernel.
     """
     #Create synthetic signal from the real one
-    f_sampling = float(signal.sample_rate/(u.Hz)) # hz
+    f_sampling = signal.sample_rate.value # hz
     duration   = signal.times[-1]-signal.times[0] #sec
     nb_measure = duration*(1/f_sampling)
-    t_0        = float(signal.t0.value)
+    t_0        = signal.t0.value
 
     t1=signal.times[0].value
     t2=signal.times[-1].value
